# ====================================================
# Presentation Eva
# ====================================================

# ----------------------------------------------------
# How does R work
# ----------------------------------------------------
# R is based on objects.
# You can create new objects just by defining what is in the object
x=12
y=c(2,4,6,8,10)
# You can view the object
x
y
# You can view all the objects you have in your session
ls()
# You can remove an object from your session
rm(x)
ls()
# All reserved words and function names should not be used as object names
# For example list is a reserved word, you can see it when you ask for it. List is a basic type of object in R
list
# In R you can ask for help by typing a question mark before an object type or function 
# The help documentation will appear in RStudio in the right lower corner in the tab "Help"
?list
# A normal name that is not a reserved word and that not exists in your session will give
# you a normal error "Error: object not found"
x1

# R works with packages, that add functionality to your code. 
# For example, the package sqldf allows you to make sequel queries in your R code
# For example, the package ggplot2 allows you to make fancy graphics
# In order to install a package, you should go in the menu to "tools"->"Install Packages",
# and then search or type the package you want to install
# you need to be connected to the internet in order to install packages
# The packages need to be installed once. 
# But each time a new session is started, they need to be loaded!!
# This is done by
library(sqldf)
library(ggplot2)



# ----------------------------------------------------
# Fixing the location of the project and the database and some parameters
# ----------------------------------------------------

# It is good practice to define beforehand the project directory, so that you avoid hard-coded links in your R-code further down
projectdir="C:/Projects/R demo/"
inputdir=paste(projectdir,"Input/",sep="")
outputdir=paste(projectdir,"Output/",sep="")

# For this presentation, we store the countrynames in variables, to avoid to have to specify the names each time further in the R-code
countryName1="C1"
countryName2="C2"
countryName3="C3"

# ----------------------------------------------------
# Reading in the data
# ----------------------------------------------------

# We first read in the database into R
data1=read.table(file=paste(inputdir,"data1.csv",sep=""),header=TRUE,sep=",")

# Note that these data is fake data, that was generated for the purpose of this demo
# It only contains part of the columns that are in the final database, to make it easy to understand the demo
# We only consider 3 countries, and there is only one urinary biomarker that is available in this database
# sampling is done over 4 years (2014-2017)

# ----------------------------------------------------
# Visualizing the data
# ----------------------------------------------------
dim(data1)
# We can visualize the first rows of this dataset by using the R function head. 
head(data1)
# The last rows can be shown by the R function tail
tail(data1)
# if you want to specify yourself the rows, then you can specify the rownumbers.
data1[10:12,]
# If you want to limit the columns you want to visualize, you can specify the columnnames...
data1[1,which(names(data1) %in% c("id_sample","id_subject","sex","country","smoking","urinary_biomarker"))]
# If you want to visualize all values of a certain column, then you can specify the name of the column
data1$bmi

# The dataset you are visualising is called a data frame in R. Data frames are tabular data objects. 
# Unlike a matrix in data frame each column can contain different modes of data. 
# The first column can be numeric while the second column can be character and third column can be logical. 
# It is a list of vectors of equal length

# ----------------------------------------------------
# Getting to know your data - descriptive statistics
# ----------------------------------------------------

# How do the urinary biomarker data look like
# ----------------------------------------------------
# The function summary gives you minimum, maximum, 1st and 3rd quantiles, median and mean, 
# and number of missing values, in case your variable is numeric
summary(data1$urinary_biomarker)
# note that there are some missing data
class(data1$urinary_biomarker)

# How many samples are there availabe for this urinary biomarker per country
# ----------------------------------------------------
summary(data1$country)
# Be careful to note that there are some missing values in the urinary biomarker data
summary(data1$country[which(!is.na(data1$urinary_biomarker))])
# Note that the function summary gives results depending on the type of data you apply it to.
# If you apply it to a factor, then it gives the number of results per factor
class(data1$country)

# How many males and females are there per country
# ----------------------------------------------------
table(data1$country,data1$sex)

# How many are smoking per country
# ----------------------------------------------------
table(data1$country,data1$smoking)

# How is bmi divided by country and sex
# ----------------------------------------------------
# You can look at the data per subgroup
summary(data1$bmi[which(data1$country==countryName1 & data1$sex=="M")])
summary(data1$bmi[which(data1$country==countryName1 & data1$sex=="F")])
summary(data1$bmi[which(data1$country==countryName2 & data1$sex=="M")])
summary(data1$bmi[which(data1$country==countryName2 & data1$sex=="F")])
summary(data1$bmi[which(data1$country==countryName3 & data1$sex=="M")])
summary(data1$bmi[which(data1$country==countryName3 & data1$sex=="F")])

# Or you can visualize it with histograms or with a boxplot
# There are different packages in R in order to make graphs
# The standard way of making graphs is with plot statement to make a scatterplot or with hist statement, to make a histogram
# You don't need extra packages in order to make this kind of graphs
png(file=paste(outputdir,"histogram_BMI.png",sep=""),width = 500, height = 700, units = "px")
par(mfrow=c(3,2))
hist(data1$bmi[which(data1$country==countryName1 & data1$sex=="M")],breaks=seq(0,ceiling(max(data1$bmi)),1),freq=FALSE,xlim=c(0,max(data1$bmi)),main=paste("country=",countryName1," - sex=M",sep=""),xlab="BMI")
hist(data1$bmi[which(data1$country==countryName1 & data1$sex=="F")],breaks=seq(0,ceiling(max(data1$bmi)),1),freq=FALSE,xlim=c(0,max(data1$bmi)),main=paste("country=",countryName1," - sex=F",sep=""),xlab="BMI")
hist(data1$bmi[which(data1$country==countryName2 & data1$sex=="M")],breaks=seq(0,ceiling(max(data1$bmi)),1),freq=FALSE,xlim=c(0,max(data1$bmi)),main=paste("country=",countryName2," - sex=M",sep=""),xlab="BMI")
hist(data1$bmi[which(data1$country==countryName2 & data1$sex=="F")],breaks=seq(0,ceiling(max(data1$bmi)),1),freq=FALSE,xlim=c(0,max(data1$bmi)),main=paste("country=",countryName2," - sex=F",sep=""),xlab="BMI")
hist(data1$bmi[which(data1$country==countryName3 & data1$sex=="M")],breaks=seq(0,ceiling(max(data1$bmi)),1),freq=FALSE,xlim=c(0,max(data1$bmi)),main=paste("country=",countryName3," - sex=M",sep=""),xlab="BMI")
hist(data1$bmi[which(data1$country==countryName3 & data1$sex=="F")],breaks=seq(0,ceiling(max(data1$bmi)),1),freq=FALSE,xlim=c(0,max(data1$bmi)),main=paste("country=",countryName3," - sex=F",sep=""),xlab="BMI")
dev.off()
# Note that the first and the last line of this piece or code will make sure that your plot is saved on disk
# do not forget the dev.off(), otherwise your graph keeps on being locked for further editing!
# If you want to see your graph in the "Plots" window, then run it without the first and last line

# There is the ggplot2 package. This package requires some training time, but if you can work with it
# you can create very nice graphs to be used in papers
# The package ggplot2 is already loaded in the beginning of this program
data1$label=paste(data1$country,"-",data1$sex)
p1 <- ggplot(data1, aes(x=label, y=bmi)) +  geom_boxplot(width=.5,outlier.size=1.5, outlier.shape=21) 
p1<-p1+theme_bw(base_size = 25)
p1<-p1+theme(axis.text.x = element_text(angle = 45, hjust = 1))
p1 = p1 + stat_summary(fun.y="mean", geom="point", shape=23, size=3, fill="white")
p1 <- p1 + xlab("")  + ylab("BMI")
print(p1) 
figure1<-last_plot()
ggsave(figure1,file=paste(outputdir,"boxplot_BMI.png",sep=""),width=15,height=10)


# We can make BMI categorical
# ----------------------------------------------------
data1$bmi
data1$bmi_cat=""
data1$bmi_cat[which (data1$bmi<21 & data1$sex=="F")]="low bmi"
data1$bmi_cat[which (data1$bmi>=21 & data1$bmi<=25 & data1$sex=="F")]="avg bmi"
data1$bmi_cat[which (data1$bmi>25 & data1$sex=="F")]="high bmi"
data1$bmi_cat[which (data1$bmi<19 & data1$sex=="M")]="low bmi"
data1$bmi_cat[which (data1$bmi>=19 & data1$bmi<=24 & data1$sex=="M")]="avg bmi"
data1$bmi_cat[which (data1$bmi>24 & data1$sex=="M")]="high bmi"
data1$bmi_cat=factor(x = data1$bmi_cat, levels= c("low bmi","avg bmi","high bmi"), labels = c("low bmi","avg bmi","high bmi"))
summary(data1$bmi_cat[which(data1$country==countryName1)])
summary(data1$bmi_cat[which(data1$country==countryName2)])
summary(data1$bmi_cat[which(data1$country==countryName3)])

# age category
# ----------------------------------------------------
# (eva, zelfde als hierboven voor BMI. Als je de categories kent, wil ik het wel uitschrijven)

# isced distribution
# ----------------------------------------------------
library(sqldf)
data2=sqldf("select country,sex,isced,count(*) as total from data1 group by country, sex,isced")
p1<-ggplot(data2, aes(x=isced, y=total)) + geom_bar(stat="identity") + facet_grid(country ~ sex)
p1 <- p1+ theme_bw(base_size = 25)
p1 <- p1 + xlab("")  + ylab("No. of occurences")                                                                       # add x and y labels
p1 <- p1 + theme(legend.position="none")
print(p1) 
figure1<-last_plot()
ggsave(figure1,file=paste(outputdir,"barplot_isced.png",sep=""),width=10,height=15)



# smoking distribution
# ----------------------------------------------------
data1$smoking_cat=factor(x=data1$smoking,levels=c(0,1),labels=c("NO","YES"))
data2=sqldf("select country,sex,smoking_cat,count(*) as total from data1 group by country, sex,smoking_cat")
# Note that the previous line works because the package sqldf is already loaded in the beginning of the program
p1<-ggplot(data2, aes(x=smoking_cat, y=total)) + geom_bar(stat="identity") + facet_grid(country ~ sex)
p1 <- p1+ theme_bw(base_size = 25)
p1 <- p1 + xlab("")  + ylab("No. of occurences")                                                                       # add x and y labels
p1 <- p1 + theme(legend.position="none")
print(p1) 
figure1<-last_plot()
ggsave(figure1,file=paste(outputdir,"barplot_smoking.png",sep=""),width=10,height=15)



# samplingyear
# ----------------------------------------------------
data1$samplingyear_cat=factor(x=data1$samplingyear,levels=unique(data1$samplingyear)[order(unique(data1$samplingyear))],labels=unique(data1$samplingyear)[order(unique(data1$samplingyear))])
summary(data1$samplingyear_cat)
table(data1$samplingyear_cat,data1$country)


# urinary_biomarker - How much above loq (in percentage), how much below, and how much -1,-2,-3
# ----------------------------------------------------
percentageMinus3=length(which(data1$urinary_biomarker==-3))/dim(data1)[1]*100
percentageMinus2=length(which(data1$urinary_biomarker==-2))/dim(data1)[1]*100
percentageMinus1=length(which(data1$urinary_biomarker==-1))/dim(data1)[1]*100
percentageAboveLOQ=length(which(data1$urinary_biomarker>0))/dim(data1)[1]*100
percentageNA=length(which(is.na(data1$urinary_biomarker)))/dim(data1)[1]*100
percentageMinus3
percentageMinus2
percentageMinus1
percentageAboveLOQ
percentageNA

# create a new variable that indicates if a value is above LOQ
data1$valueAboveLOQ=NaN
data1$valueAboveLOQ[which(data1$urinary_biomarker %in% c(-1,-2,-3))]=0
data1$valueAboveLOQ[which(data1$urinary_biomarker >0)]=1
data1$valueAboveLOQ=as.factor(data1$valueAboveLOQ)
summary(data1$valueAboveLOQ)

# urinary biomarker - all values that are lower than loq, we replace by loq/2
# ----------------------------------------------------
summary(data1$urinary_biomarker)
data1$urinary_biomarker_imp=data1$urinary_biomarker
data1$urinary_biomarker_imp[which(data1$urinary_biomarker %in% c(-1,-2,-3))]=data1$urinary_biomarker_loq[which(data1$urinary_biomarker %in% c(-1,-2,-3))]/2

# make a distribution plot
# ----------------------------------------------------
png(file=paste(outputdir,"distribution_biomarker.png",sep=""),width = 500, height = 700, units = "px")
par(mfrow=c(2,1))
h<-hist(data1$urinary_biomarker_imp, breaks=20, col="red", xlab="urinary biomarker", main="Histogram with Normal Curve") 
h<-hist(data1$urinary_biomarker_imp[which(data1$urinary_biomarker_imp<30)], breaks=20, col="red", xlab="urinary biomarker", main="Histogram with Normal Curve") 
xfit<-seq(min(data1$urinary_biomarker_imp[which(data1$urinary_biomarker_imp<30)],na.rm=TRUE),max(data1$urinary_biomarker_imp[which(data1$urinary_biomarker_imp<30)],na.rm=TRUE),length=400) 
yfit<-dnorm(xfit,mean=mean(data1$urinary_biomarker_imp[which(data1$urinary_biomarker_imp<30)],na.rm=TRUE),sd=sd(data1$urinary_biomarker_imp[which(data1$urinary_biomarker_imp<30)],na.rm=TRUE)) 
yfit <- yfit*diff(h$mids[1:2])*length(data1$urinary_biomarker_imp[which(data1$urinary_biomarker_imp<30)]) 
lines(xfit, yfit, col="blue", lwd=2)
dev.off()

# It is not normally distributed, take log2
# ----------------------------------------------------
png(file=paste(outputdir,"distribution_biomarker_ln.png",sep=""),width = 500, height = 700, units = "px")
data1$log_urinary_biomarker_imp=log(data1$urinary_biomarker_imp)
summary(data1$log_urinary_biomarker_imp)
par(mfrow=c(2,1))
h<-hist(data1$log_urinary_biomarker_imp, breaks=20, col="red", xlab="urinary biomarker", main="Histogram with Normal Curve") 
h<-hist(data1$log_urinary_biomarker_imp[which(data1$log_urinary_biomarker_imp<4)], breaks=20, col="red", xlab="urinary biomarker", main="Histogram with Normal Curve") 
xfit<-seq(min(data1$log_urinary_biomarker_imp[which(data1$log_urinary_biomarker_imp<4)],na.rm=TRUE),max(data1$log_urinary_biomarker_imp[which(data1$log_urinary_biomarker_imp<4)],na.rm=TRUE),length=400) 
yfit<-dnorm(xfit,mean=mean(data1$log_urinary_biomarker_imp[which(data1$log_urinary_biomarker_imp<4)],na.rm=TRUE),sd=sd(data1$log_urinary_biomarker_imp[which(data1$log_urinary_biomarker_imp<4)],na.rm=TRUE)) 
yfit <- yfit*diff(h$mids[1:2])*length(data1$log_urinary_biomarker_imp[which(data1$log_urinary_biomarker_imp<4)]) 
lines(xfit, yfit, col="blue", lwd=2)
dev.off()

# make a boxplot of log_urinary_biomarker_imp per country and sex
# ----------------------------------------------------
# label has already been defined before as data1$label=paste(data1$country,"-",data1$sex)
p1 <- ggplot(data1, aes(x=label, y=log_urinary_biomarker_imp)) +  geom_boxplot(width=.5,outlier.size=1.5, outlier.shape=21) 
p1<-p1+theme_bw(base_size = 25)
p1<-p1+theme(axis.text.x = element_text(angle = 45, hjust = 1))
p1 = p1 + stat_summary(fun.y="mean", geom="point", shape=23, size=3, fill="white")
p1 <- p1 + xlab("")  + ylab("log_urinary_biomarker_imp")
print(p1) 
figure1<-last_plot()
ggsave(figure1,file=paste(outputdir,"boxplot_log_urinary_biomarker_imp_per_country_sex.png",sep=""),width=15,height=10)


# Calculate geometrical mean for the whole group 
# ----------------------------------------------------
indx1=which(!is.na(data1$urinary_biomarker_imp))
n=length(indx1)
n
sd=sd(log(data1$urinary_biomarker_imp[indx1]))
sd
mean1=mean(log(data1$urinary_biomarker_imp[indx1]))
res1=data.frame(what="all data",geomean=exp(mean1),CILowerLimit=exp(mean1-1.96*sd/sqrt(n)),CIUpperLimit=exp(mean1+1.96*sd/sqrt(n)))
res1

# time trends - show the geometrical average (+ interval) per year of the urinary biomarker for all data together
# ----------------------------------------------------
res2=data.frame(what=character(0),CILowerLimit=numeric(0),CIUpperLimit=numeric(0))
for (year in unique(data1$samplingyear)[order(unique(data1$samplingyear))]) {
  indx1=which(!is.na(data1$urinary_biomarker_imp) & data1$samplingyear==year)
  n=length(indx1)
  n
  sd=sd(log(data1$urinary_biomarker_imp[indx1]))
  sd
  mean1=mean(log(data1$urinary_biomarker_imp[indx1]))
  res2=rbind(res2,data.frame(what=paste(year),mean=exp(mean1),CILowerLimit=exp(mean1-1.96*sd/sqrt(n)),CIUpperLimit=exp(mean1+1.96*sd/sqrt(n))))
}
res2

# plot of geometric means and CI
png(file=paste(outputdir,"urinary_biomarker_geomean_CI_perYear.png",sep=""),width = 500, height = 700, units = "px")
par(mfrow=c(1,1))
plot(res2$what,res2$mean,ylim=c(trunc(min(c(min(res2$mean),min(res2$CILowerLimit),min(res2$CIUpperLimit)))),ceiling(max(c(max(res2$mean),max(res2$CILowerLimit),max(res2$CIUpperLimit))))),main="geometric mean and CI per samplingyear")
points(res2$what,res2$CILowerLimit,pch=15)
points(res2$what,res2$CIUpperLimit,pch=15)
dev.off()

# boxplot per year
data1$samplingyear=as.factor(data1$samplingyear)
p1 <- ggplot(data1, aes(x=samplingyear, y=log_urinary_biomarker_imp)) +  geom_boxplot(width=.5,outlier.size=1.5, outlier.shape=21) 
p1<-p1+theme_bw(base_size = 25)
p1<-p1+theme(axis.text.x = element_text(angle = 45, hjust = 1))
p1 = p1 + stat_summary(fun.y="mean", geom="point", shape=23, size=3, fill="white")
p1 <- p1 + xlab("")  + ylab("log_urinary_biomarker_imp")
print(p1) 
figure1<-last_plot()
ggsave(figure1,file=paste(outputdir,"boxplot_log_urinary_biomarker_imp_per_year.png",sep=""),width=15,height=10)

#anova
aovobject=aov(log_urinary_biomarker_imp ~ samplingyear,data=data1)
summary(aovobject)

# geographical trends - do the same thing as above but for the 3 countries seperately
# ----------------------------------------------------
res3=data.frame(what=character(0),CILowerLimit=numeric(0),CIUpperLimit=numeric(0))
for (country in unique(data1$country)[order(unique(data1$country))]) {
  indx1=which(!is.na(data1$urinary_biomarker_imp) & data1$country==country)
  n=length(indx1)
  n
  sd=sd(log(data1$urinary_biomarker_imp[indx1]))
  sd
  mean1=mean(log(data1$urinary_biomarker_imp[indx1]))
  res3=rbind(res3,data.frame(what=paste("country",country),mean=exp(mean1),CILowerLimit=exp(mean1-1.96*sd/sqrt(n)),CIUpperLimit=exp(mean1+1.96*sd/sqrt(n))))
}
res3

# plot of geometric means and CI
png(file=paste(outputdir,"urinary_biomarker_geomean_CI_perCountry.png",sep=""),width = 500, height = 700, units = "px")
par(mfrow=c(1,1))
plot(res3$what,res3$mean,ylim=c(trunc(min(c(min(res3$mean),min(res3$CILowerLimit),min(res3$CIUpperLimit)))),ceiling(max(c(max(res3$mean),max(res3$CILowerLimit),max(res3$CIUpperLimit))))),main="geometric mean and CI per country")
points(res3$what,res3$CILowerLimit,pch=15)
points(res3$what,res3$CIUpperLimit,pch=15)
dev.off()

# boxplot per country
class(data1$country)
p1 <- ggplot(data1, aes(x=country, y=log_urinary_biomarker_imp)) +  geom_boxplot(width=.5,outlier.size=1.5, outlier.shape=21) 
p1<-p1+theme_bw(base_size = 25)
p1<-p1+theme(axis.text.x = element_text(angle = 45, hjust = 1))
p1 = p1 + stat_summary(fun.y="mean", geom="point", shape=23, size=3, fill="white")
p1 <- p1 + xlab("")  + ylab("log_urinary_biomarker_imp")
print(p1) 
figure1<-last_plot()
ggsave(figure1,file=paste(outputdir,"boxplot_log_urinary_biomarker_imp_per_country.png",sep=""),width=15,height=10)


# anova
aovobject=aov(log_urinary_biomarker_imp ~ country,data=data1)
summary(aovobject)

# t test : urinary biomarker - difference between men and women
# ----------------------------------------------------
res4=data.frame(what=character(0),CILowerLimit=numeric(0),CIUpperLimit=numeric(0))
for (sex in unique(data1$sex)[order(unique(data1$sex))]) {
  indx1=which(!is.na(data1$urinary_biomarker_imp) & data1$sex==sex)
  n=length(indx1)
  n
  sd=sd(log(data1$urinary_biomarker_imp[indx1]))
  sd
  mean1=mean(log(data1$urinary_biomarker_imp[indx1]))
  res4=rbind(res4,data.frame(what=paste("sex",sex),mean=exp(mean1),CILowerLimit=exp(mean1-1.96*sd/sqrt(n)),CIUpperLimit=exp(mean1+1.96*sd/sqrt(n))))
}
res4

# plot of geometric means and CI
png(file=paste(outputdir,"urinary_biomarker_geomean_CI_perSex.png",sep=""),width = 500, height = 700, units = "px")
par(mfrow=c(1,1))
plot(res4$what,res4$mean,ylim=c(trunc(min(c(min(res4$mean),min(res4$CILowerLimit),min(res4$CIUpperLimit)))),ceiling(max(c(max(res4$mean),max(res4$CILowerLimit),max(res4$CIUpperLimit))))),main="geometric mean and CI per sex")
points(res4$what,res4$CILowerLimit,pch=15)
points(res4$what,res4$CIUpperLimit,pch=15)
dev.off()

# boxplot per sex
class(data1$sex)
p1 <- ggplot(data1, aes(x=sex, y=log_urinary_biomarker_imp)) +  geom_boxplot(width=.5,outlier.size=1.5, outlier.shape=21) 
p1<-p1+theme_bw(base_size = 25)
p1<-p1+theme(axis.text.x = element_text(angle = 45, hjust = 1))
p1 = p1 + stat_summary(fun.y="mean", geom="point", shape=23, size=3, fill="white")
p1 <- p1 + xlab("")  + ylab("log_urinary_biomarker_imp")
print(p1) 
figure1<-last_plot()
ggsave(figure1,file=paste(outputdir,"boxplot_log_urinary_biomarker_imp_per_sex.png",sep=""),width=15,height=10)



t.test(log_urinary_biomarker_imp ~ sex, data = data1)
boxplot




